@@ -1,32 +1,36 @@
 from unittest import TestCase
 import regex
-from ctparse.types import RegexMatch
+from ctparse.types import RegexMatch, Artifact
 from ctparse.rule import dimension, predicate, regex_match, rule
 
 
-class TestClassA:
+class TestClassA(Artifact):
     predA = 1
 
 
-class TestClassB:
+class TestClassB(Artifact):
     pass
 
 
 class TestRule(TestCase):
     def test_empty_regex_match_not_allowed(self):
         with self.assertRaises(ValueError):
-            rule(r'')
+            rule(r"")
         with self.assertRaises(ValueError):
-            rule(r'[a-z]*')
-        self.assertIsNotNone(rule(r'This long string must not match as this expression '
-                                  'will be part of the system unless ctparse is reloaded'))
+            rule(r"[a-z]*")
+        self.assertIsNotNone(
+            rule(
+                r"This long string must not match as this expression "
+                "will be part of the system unless ctparse is reloaded"
+            )
+        )
 
-    def test_consequtive_regex_not_allowed(self):
+    def test_consecutive_regex_not_allowed(self):
         with self.assertRaises(ValueError):
-            rule(r'one', r'two')
+            rule(r"one", r"two")
 
     def test_regex_match(self):
-        m = next(regex.finditer('(?P<R1>x)', 'x'))
+        m = next(regex.finditer("(?P<R1>x)", "x"))
         r = RegexMatch(1, m)
         self.assertTrue(regex_match(1)(r))
         self.assertFalse(regex_match(1)(TestClassA()))
@@ -36,5 +40,5 @@ class TestRule(TestCase):
         self.assertFalse(dimension(TestClassA)(TestClassB()))
 
     def test_predicate(self):
-        self.assertTrue(predicate('predA')(TestClassA()))
-        self.assertFalse(predicate('predA')(TestClassB()))
+        self.assertTrue(predicate("predA")(TestClassA()))
+        self.assertFalse(predicate("predA")(TestClassB()))
